# __main__.py

import pandasklar as pak
from importlib.metadata import version

def main():
    print('Hello pandasklar', version('pandasklar') )

    
if __name__ == "__main__":
    main()    
    
    
    
    
